﻿using System;
using System.Collections.ObjectModel;
using System.Windows;
using System.Windows.Controls;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace CSHowDoISamples
{
    public partial class DisplayASimpleMap : UserControl
    {
        private System.Windows.Forms.Timer timer;

        public DisplayASimpleMap()
        {
            InitializeComponent();
        }

        private void GenerateLayers(LayerOverlay overlay, int number)
        {
            for (int i = 0; i < number; i++)
            {
                ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(@"..\..\SampleData\Data\Countries02.shp", ShapeFileReadWriteMode.ReadOnly);
                worldLayer.Name = i.ToString();
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
                worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                overlay.Layers.Add(worldLayer);
            }
        }

        private void WpfMap_Loaded(object sender, RoutedEventArgs e)
        {
            timer = new System.Windows.Forms.Timer();
            timer.Tick += timer_Tick;
            timer.Interval = 300;

            Map1.MapUnit = GeographyUnit.DecimalDegree;
            Map1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);
            Map1.CurrentExtent = new RectangleShape(-20.0, 20.0, -20.0, -20.0);
            Map1.CurrentScale = 10000000;

            LayerOverlay overlay = new LayerOverlay();
            overlay.Layers.Add(new BackgroundLayer(new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean)));
            GenerateLayers(overlay, 50);

            Map1.Overlays.Add(overlay);

            Map1.Refresh();
        }

        private void timer_Tick(object sender, EventArgs e)
        {
            Refresh();
        }

        private void btnTest_Click(object sender, RoutedEventArgs e)
        {
            if (timer.Enabled == true)
            {
                timer.Stop();
            }
            else
            {
                timer.Start();
            }
        }

        private void Refresh()
        {
            Random random = new Random();
            int x = random.Next(-180, 180);
            int y = random.Next(-90, 90);

            ShapeFileFeatureLayer layer = (Map1.Overlays[0] as LayerOverlay).Layers[1] as ShapeFileFeatureLayer;

            if (!layer.IsOpen)
            {
                layer.Open();
            }

            Collection<Feature> features = layer.QueryTools.GetFeaturesNearestTo(new PointShape(x, y), GeographyUnit.DecimalDegree, 1, ReturningColumnsType.AllColumns);

            resultLabel.Text = features[0].Id.ToString();

            Map1.CenterAt(new PointShape(x, y));
            Map1.Refresh();
        }
    }
}